<?php

namespace Drupal\role_node_access\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldItemInterface;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Plugin implementation of the 'role_node_access_type' field type.
 *
 * @FieldType(
 *   id = "role_node_access_type",
 *   label = @Translation("Role-based Access (Node Only)"),
 *   description = @Translation("A field to control access to content based on role."),
 *   category = @Translation("Access Control"),
 *   default_widget = "role_node_access_widget",
 *   default_formatter = "role_node_access_formatter"
 * )
 */
class RoleNodeAccessType extends FieldItemBase implements FieldItemInterface {

  /**
   * {@inheritdoc}
   */
  protected static $propertyDefinitions;

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    return [
      'columns' => [
        'value' => [
          'type' => 'text',
          'size' => 'small',
          'not null' => FALSE,
        ],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    if (!isset(static::$propertyDefinitions)) {
      static::$propertyDefinitions = [
        'value' => DataDefinition::create('string')->setLabel(t('Role Required')),
      ];
    }
    return static::$propertyDefinitions;
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    $value = $this->get('value')->getValue();
    return $value === NULL || $value === '';
  }

}
